from setuptools import setup, find_packages
setup(
 name = 'harvestnet',
 version = '0.0.2',
 description = 'HarvestNet',
 long_description = 'HarvestNet',
 author = 'waterlily',
 author_email = 'b1929595403@gmail.com',
 platforms = 'any',
 python_requires = '>=3.7.*',
 install_requires = [],
 package_dir = {'': 'HarvestNet'},
 packages = find_packages('HarvestNet')
 )
